@@ -45,12 +45,14 @@ typedef struct
     GtkWidget * date_edit;
     GtkWidget * num_edit;
     GtkWidget * tnum_edit;
+    GtkWidget * assoc_edit;
 
     GtkWidget *duplicate_title_label; // GtkLabel
     GtkWidget *duplicate_table; // GtkTable
     GtkWidget *date_label; // GtkLabel
     GtkWidget *num_label; // GtkLabel
     GtkWidget *tnum_label; // GtkLabel
+    GtkWidget *assoc_label; //GtkLabel
 } DupTransDialog;
 
 /* Parses the string value and returns true if it is a
@@ -108,8 +110,9 @@ gnc_dup_trans_dialog_create (GtkWidget * parent, DupTransDialog *dt_dialog,
     dialog = GTK_WIDGET(gtk_builder_get_object (builder, "duplicate_transaction_dialog"));
     dt_dialog->dialog = dialog;
 
-    // Set the style context for this dialog so it can be easily manipulated with css
-    gnc_widget_set_style_context (GTK_WIDGET(dialog), "GncDupTransDialog");
+    // Set the name for this dialog so it can be easily manipulated with css
+    gtk_widget_set_name (GTK_WIDGET(dialog), "gnc-id-duplicate-transaction");
+    gnc_widget_style_context_add_class (GTK_WIDGET(dialog), "gnc-class-transactions");
 
     /* parent */
     if (parent != NULL)
@@ -169,6 +172,11 @@ gnc_dup_trans_dialog_create (GtkWidget * parent, DupTransDialog *dt_dialog,
         else
             gtk_entry_set_text (GTK_ENTRY (tnum_spin), "");
     }
+    /* Transaction Association */
+    {
+        dt_dialog->assoc_label = GTK_WIDGET(gtk_builder_get_object (builder, "assoc_label"));
+        dt_dialog->assoc_edit = GTK_WIDGET(gtk_builder_get_object (builder, "assoc_check_button"));
+    }
 
     gtk_builder_connect_signals_full (builder, gnc_builder_connect_full_func, dt_dialog);
 
@@ -176,10 +184,12 @@ gnc_dup_trans_dialog_create (GtkWidget * parent, DupTransDialog *dt_dialog,
 }
 
 static gboolean
-gnc_dup_trans_dialog_internal (GtkWidget * parent, const char* title,
+gnc_dup_trans_dialog_internal (GtkWidget * parent,
+                               const char* window_title, const char* title,
                                gboolean show_date, time64 *date_p,
                                GDate *gdate_p, const char *num, char **out_num,
-                               const char *tnum, char **out_tnum)
+                               const char *tnum, char **out_tnum,
+                               const char *tassoc, char **out_tassoc)
 {
     DupTransDialog *dt_dialog;
     GtkWidget *entry;
@@ -210,6 +220,9 @@ gnc_dup_trans_dialog_internal (GtkWidget * parent, const char* title,
         gtk_widget_grab_focus (entry);
     }
 
+    if (window_title)
+        gtk_window_set_title (GTK_WINDOW (dt_dialog->dialog), window_title);
+
     if (title)
     {
         gchar *full_text = g_strdup_printf("<b>%s</b>", title);
@@ -234,7 +247,7 @@ gnc_dup_trans_dialog_internal (GtkWidget * parent, const char* title,
     if (!show_date && !tnum)
     {
         // The "date" and the "tnum" fields aren't being asked for, this is a split copy
-        gtk_label_set_markup(GTK_LABEL (dt_dialog->num_label), _("Action/Number:"));
+        gtk_label_set_markup(GTK_LABEL (dt_dialog->num_label), _("Action/Number"));
     }
 
     if (tnum)
@@ -243,6 +256,17 @@ gnc_dup_trans_dialog_internal (GtkWidget * parent, const char* title,
         gtk_entry_set_activates_default(GTK_ENTRY(dt_dialog->tnum_edit), TRUE);
     }
 
+    if (tassoc)
+    {
+        gtk_widget_set_visible(dt_dialog->assoc_label, TRUE);
+        gtk_widget_set_visible(dt_dialog->assoc_edit, TRUE);
+    }
+    else
+    {
+        gtk_widget_set_visible(dt_dialog->assoc_label, FALSE);
+        gtk_widget_set_visible(dt_dialog->assoc_edit, FALSE);
+    }
+
     result = gtk_dialog_run (GTK_DIALOG (dt_dialog->dialog));
 
     if (result == GTK_RESPONSE_OK)
@@ -255,6 +279,11 @@ gnc_dup_trans_dialog_internal (GtkWidget * parent, const char* title,
             *out_num = g_strdup (gtk_entry_get_text (GTK_ENTRY (dt_dialog->num_edit)));
         if (tnum)
             *out_tnum = g_strdup (gtk_entry_get_text (GTK_ENTRY (dt_dialog->tnum_edit)));
+        if (tassoc)
+        {
+            if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(dt_dialog->assoc_edit)))
+                *out_tassoc = g_strdup (tassoc);
+        }
         ok = TRUE;
     }
     else
@@ -269,10 +298,11 @@ gnc_dup_trans_dialog_internal (GtkWidget * parent, const char* title,
 gboolean
 gnc_dup_trans_dialog (GtkWidget * parent, const char* title, gboolean show_date,
                       time64 *date_p, const char *num, char **out_num,
-                      const char *tnum, char **out_tnum)
+                      const char *tnum, char **out_tnum,
+                      const char *tassoc, char **out_tassoc)
 {
-    return gnc_dup_trans_dialog_internal(parent, title, show_date, date_p, NULL,
-                                         num, out_num, tnum, out_tnum);
+    return gnc_dup_trans_dialog_internal(parent, NULL, title, show_date, date_p, NULL,
+                                         num, out_num, tnum, out_tnum, tassoc, out_tassoc);
 }
 
 gboolean
@@ -283,8 +313,16 @@ gnc_dup_trans_dialog_gdate (GtkWidget * parent, GDate *gdate_p,
     g_assert(gdate_p);
 
     tmp_time = gdate_to_time64 (*gdate_p);
-    return gnc_dup_trans_dialog_internal(parent, NULL, TRUE, &tmp_time, gdate_p,
-                                         num, out_num, NULL, NULL);
+    return gnc_dup_trans_dialog_internal(parent, NULL, NULL, TRUE, &tmp_time, gdate_p,
+                                         num, out_num, NULL, NULL, NULL, NULL);
+}
+
+gboolean
+gnc_dup_time64_dialog (GtkWidget * parent, const char *window_title,
+                       const char* title, time64 *date)
+{
+    return gnc_dup_trans_dialog_internal(parent, window_title, title, TRUE, date, NULL,
+                                         NULL, NULL, NULL, NULL, NULL, NULL);
 }
 
 gboolean
@@ -294,6 +332,7 @@ gnc_dup_date_dialog (GtkWidget * parent, const char* title, GDate *gdate_p)
     g_assert(gdate_p);
 
     tmp_time = gdate_to_time64(*gdate_p);
-    return gnc_dup_trans_dialog_internal(parent, title, TRUE, &tmp_time, gdate_p,
-                                         NULL, NULL, NULL, NULL);
+    return gnc_dup_trans_dialog_internal(parent, NULL, title, TRUE, &tmp_time, gdate_p,
+                                         NULL, NULL, NULL, NULL, NULL, NULL);
 }
+
