@@ -920,7 +920,7 @@ variable_value_changed_cb(GtkCellRendererText *cell,
                           const gchar *value,
                           GncSxSinceLastRunDialog *dialog)
 {
-    GncSxVariable *var;
+    GncSxVariable *var = NULL;
     GncSxInstance *inst;
     GtkTreeIter tree_iter;
     gnc_numeric parsed_num;
@@ -973,8 +973,9 @@ gnc_ui_sx_since_last_run_dialog (GtkWindow *parent, GncSxInstanceModel *sx_insta
     dialog->dialog = GTK_WIDGET(gtk_builder_get_object (builder, "since_last_run_dialog"));
     gtk_window_set_transient_for (GTK_WINDOW (dialog->dialog), parent);
 
-    // Set the style context for this dialog so it can be easily manipulated with css
-    gnc_widget_set_style_context (GTK_WIDGET(dialog->dialog), "GncSxSinceLastRunDialog");
+    // Set the name of this dialog so it can be easily manipulated with css
+    gtk_widget_set_name (GTK_WIDGET(dialog->dialog), "gnc-id-sx-since-last-run");
+    gnc_widget_style_context_add_class (GTK_WIDGET(dialog->dialog), "gnc-class-sx");
 
     dialog->editing_model = gnc_sx_slr_tree_model_adapter_new(sx_instances);
     dialog->review_created_txns_toggle = GTK_TOGGLE_BUTTON(gtk_builder_get_object (builder, "review_txn_toggle"));
@@ -1154,6 +1155,7 @@ dialog_response_cb(GtkDialog *dialog, gint response_id, GncSxSinceLastRunDialog
     gnc_suspend_gui_refresh();
     gnc_sx_slr_model_effect_change(app_dialog->editing_model, FALSE, &app_dialog->created_txns, &creation_errors);
     gnc_resume_gui_refresh();
+    gnc_gui_refresh_all (); // force a refresh of all registers
     if (creation_errors)
         creation_error_dialog(&creation_errors);
 
